==> carryon-fabric-1.21.1-2.2.3.3-sources.jar: tschipp/carryon/platform/services/IPlatformHelper.java <==
/*
 * GNU Lesser General Public License v3
 * Copyright (C) 2024 Tschipp
 * mrtschipp@gmail.com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package tschipp.carryon.platform.services;

import tschipp.carryon.config.BuiltConfig;
import tschipp.carryon.networking.PacketBase;

import java.util.function.BiConsumer;
import java.util.function.Function;
import net.minecraft.class_1657;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_3222;
import net.minecraft.class_8710;
import net.minecraft.class_9139;

public interface IPlatformHelper {

    /**
     * Gets the name of the current platform
     *
     * @return The name of the current platform.
     */
    String getPlatformName();

    /**
     * Checks if a mod with the given id is loaded.
     *
     * @param modId The mod to check if it is loaded.
     * @return True if the mod is loaded, false otherwise.
     */
    boolean isModLoaded(String modId);

    /**
     * Check if the game is currently in a development environment.
     *
     * @return True if in a development environment, false otherwise.
     */
    boolean isDevelopmentEnvironment();

    void registerConfig(BuiltConfig cfg);

    <T extends PacketBase, B extends class_2540> void  registerServerboundPacket(class_8710.class_9154<T> type, Class<T> clazz, class_9139<B, T> codec, BiConsumer<T, class_1657> handler, Object... args);

    <T extends PacketBase, B extends class_2540> void  registerClientboundPacket(class_8710.class_9154<T> type, Class<T> clazz, class_9139<B, T> codec, BiConsumer<T, class_1657> handler, Object... args);

    void sendPacketToServer(class_2960 id, PacketBase packet);

    void sendPacketToPlayer(class_2960 id, PacketBase packet, class_3222 player);
}

==> carryon-fabric-1.21.11-2.9.1-sources.jar: tschipp/carryon/platform/services/IPlatformHelper.java <==
/*
 * GNU Lesser General Public License v3
 * Copyright (C) 2024 Tschipp
 * mrtschipp@gmail.com
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 3 of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */

package tschipp.carryon.platform.services;

import tschipp.carryon.common.carry.CarryOnData;
import tschipp.carryon.config.BuiltConfig;
import tschipp.carryon.networking.PacketBase;

import java.util.function.BiConsumer;
import net.minecraft.class_1657;
import net.minecraft.class_2540;
import net.minecraft.class_2960;
import net.minecraft.class_3218;
import net.minecraft.class_3222;
import net.minecraft.class_8710;
import net.minecraft.class_9139;

public interface IPlatformHelper {

    /**
     * Gets the name of the current platform
     *
     * @return The name of the current platform.
     */
    String getPlatformName();

    /**
     * Checks if a mod with the given id is loaded.
     *
     * @param modId The mod to check if it is loaded.
     * @return True if the mod is loaded, false otherwise.
     */
    boolean isModLoaded(String modId);

    /**
     * Check if the game is currently in a development environment.
     *
     * @return True if in a development environment, false otherwise.
     */
    boolean isDevelopmentEnvironment();

    void registerConfig(BuiltConfig cfg);

    <T extends PacketBase, B extends class_2540> void  registerServerboundPacket(class_8710.class_9154<T> type, Class<T> clazz, class_9139<B, T> codec, BiConsumer<T, class_1657> handler, Object... args);

    <T extends PacketBase, B extends class_2540> void  registerClientboundPacket(class_8710.class_9154<T> type, Class<T> clazz, class_9139<B, T> codec, BiConsumer<T, class_1657> handler, Object... args);

    void sendPacketToServer(class_2960 id, PacketBase packet);

    void sendPacketToPlayer(class_2960 id, PacketBase packet, class_3222 player);

    default void sendPacketToAllPlayers(class_2960 id, PacketBase packet, class_3218 level) {
        for(class_3222 p : level.method_18456())
            sendPacketToPlayer(id, packet, p);
    }

    CarryOnData getCarryData(class_1657 player);

    void setCarryData(class_1657 player, CarryOnData data);

}
